@@ -40,7 +40,7 @@ class ChartNode(template.Node):
 
 def prepare_chart(input, attr=''):
     # remove whitespaces
-    input_lines = input.replace(' ', '').splitlines()
+    input_lines = input.replace(' ', '').replace('\t', '').splitlines()
 
     # build url
     lines = []
